@@ -18,13 +18,15 @@
 #' @return \item{coefficients}{Coefficients associated with  X data}
 #' @return \item{coefficients.Y}{Coefficients associated with regressing  Y on Global components X}
 #' @return \item{Components.Global}{Conctenated Components for X and Y}
-#' @return \item{Components.Group}{Components associated with groups in X and Y}
+#' @return \item{Components.Group}{Components associated with groups in X}
 #' @return \item{loadings.common}{Common vector of loadings for X and Y}
 #' @return \item{loadings.Group}{Group vector of loadings for X and Y}
 #' @return \item{expvar}{Explained variance associated with global components X}
 #' @return \item{cum.expvar.Group}{Cumulative explained varaince in groups of X and Y}
 #' @return \item{Similarity.Common.Group.load}{Cumulative similarity between group and common loadings}
 #' @return \item{Similarity.noncum.Common.Group.load}{ NonCumulative  similarity between group and common loadings}
+#' @return \item{eigenValue}{EigenValue to calculate the percentage of inertia}
+#' @return \item{Percentage.inertia.per.GroupX}{Percentages of inertia per group X}
 #' @seealso \code{\link{mgPCA}}, \code{\link{mbmgPCA}}
 #' @export
 #' @references A. Eslami, E. M. Qannari, A. Kohler and S. Bougeard (2013). Multi-group PLS
@@ -177,6 +179,15 @@ mgPLS = function(DataX, DataY, Group, ncomp=NULL, Scale=FALSE, Gcenter=FALSE, Gs
   #------------------------
   res$noncumper.inertiglobal = matrix(0, ncol=ncomp, nrow=1)
   colnames(res$noncumper.inertiglobal) = paste("Dim", 1:ncomp, sep="")
+  #---------------
+  #eigen value
+  res$eigenValue = NULL
+  #res$WeigenValue = matrix(0,ncol=ncomp,nrow=ncol(DataX))
+  #---------- Percentage.inertia.per.GroupX
+  res$Percentage.inertia.per.GroupX = matrix(0, nrow=M, ncol= ncomp)
+  rownames(res$Percentage.inertia.per.GroupX) = levels(Group)
+  colnames(res$Percentage.inertia.per.GroupX) = paste("Dim", 1:ncomp, sep="")
+  
   #=========================================================================
   #                      NIPALS algorithm for multigroup PLS data
   #=========================================================================
@@ -261,6 +272,17 @@ mgPLS = function(DataX, DataY, Group, ncomp=NULL, Scale=FALSE, Gcenter=FALSE, Gs
       covvm[iter] = sum_cov
       #---------------------------- #
     }# end of iteration
+   
+    #--------------------------------
+    #eigen value
+    VVeigen=0   #--- v=sum (Xm' * Ym)
+    for(m in 1: M){
+      VVeigen = VVeigen + (t(DataXm[[m]])%*% DataYm[[m]])
+    }
+    WWeigen=VVeigen%*%t(VVeigen)
+    #--- 2. common loadings
+   ## res$WeigenValue[,h] =  eigen(WWeigen)$vectors[,1]
+    res$eigenValue[h]   =  eigen(WWeigen)$values[1]/(N-1)^2 #eigen(WWeigen)$values[1]/(N-1)^2 
     #---------------------------- #   
     aCommonX[,h] = wTold
     TGlobalX[,h] = t 
@@ -371,6 +393,15 @@ mgPLS = function(DataX, DataY, Group, ncomp=NULL, Scale=FALSE, Gcenter=FALSE, Gs
   similarityB =similarity_function(loadings_matrices=loadings_matricesV, NAMES)
   similarityA_noncum = similarity_noncum(loadings_matrices=loadings_matricesW, NAMES)
   similarityB_noncum = similarity_noncum(loadings_matrices=loadings_matricesV, NAMES)
+ 
+  #-------------------------------------------------------------------
+  Pct_vartm = matrix(0, nrow=M, ncol= ncomp)
+  for (m in 1:M){
+    Pct_vartm[m, ] <- apply(TGroupX[[m]], 2, var) / sum(apply(TGroupX[[m]], 2, var))*100
+  }
+  
+  rownames(Pct_vartm) = levels(Group)
+  colnames(Pct_vartm) = paste("Dim", 1:H, sep="")
   #------------------------------------------------------------------
   rownames(aCommonX) = colnames(res$Concat.X)
   rownames(bCommonY) = colnames(res$Concat.Y)
@@ -385,7 +416,7 @@ mgPLS = function(DataX, DataY, Group, ncomp=NULL, Scale=FALSE, Gcenter=FALSE, Gs
     colnames(TGroupX[[m]]) = paste("Dim", 1:H, sep="")
   }
   res$Components.Global  = list(X = TGlobalX, Y = UGlobalY)
-  res$Components.Group   = list(X = TGroupX)
+  res$Components.Group   = TGroupX
   res$loadings.common    = list(X = aCommonX, Y = bCommonY)
   res$loadings.Group     = list(X = aGroupX, Y = bGroupY)
   colnames(cum.expvar.Xm) = paste("Dim", 1:H, sep="")
@@ -398,6 +429,8 @@ mgPLS = function(DataX, DataY, Group, ncomp=NULL, Scale=FALSE, Gcenter=FALSE, Gs
   
   res$Similarity.Common.Group.load          = list(X = similarityA, Y = similarityB)
   res$Similarity.noncum.Common.Group.load   = list(X = similarityA_noncum , Y = similarityB_noncum)
+  res$Percentage.inertia.per.GroupX = Pct_vartm
+  
   #----------------------------------
   class(res) = c("mgPLS", "mg")
   return(res)
